<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package bikashsoft
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @param array $args Configuration arguments.
 * @return array
 */
function bikashsoft_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'bikashsoft_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */

/**
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
function bikashsoft_setup_author() {
	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}
}
add_action( 'wp', 'bikashsoft_setup_author' );

global $bikashsoft_options;
$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function bikashsoft_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Left Sidebar', 'bikashsoft' ),
		'id'            => 'left-sidebar',
		'description'   => __( 'Display items in the Left Sidebar of the inner pages', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Right Sidebar', 'bikashsoft' ),
		'id'            => 'right-sidebar',
		'description'   => __( 'Display items in the Right Sidebar of the inner pages', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Event Sidebar', 'bikashsoft' ),
		'id'            => 'event-sidebar',
		'description'   => __( 'Display items in the Left Sidebar of the inner pages', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1>',
		'after_title'   => '</h1>',
	) );

	register_sidebar( array(
		'name'          => __( 'Blog Right Sidebar', 'bikashsoft' ),
		'id'            => 'blog-sidebar',
		'description'   => __( 'Display items for the blog category in the Right Sidebar of the inner pages', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Area One', 'bikashsoft' ),
		'id'            => 'footer-1',
		'description'   => __( 'Display items in First Footer Area', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Area Two', 'bikashsoft' ),
		'id'            => 'footer-2',
		'description'   => __( 'Display items in Second Footer Area', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Area Three', 'bikashsoft' ),
		'id'            => 'footer-3',
		'description'   => __( 'Display items in Third Footer Area', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Area Four', 'bikashsoft' ),
		'id'            => 'footer-4',
		'description'   => __( 'Display items in Fourth Footer Area', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    
    register_sidebar( array(
		'name'          => __( 'Left Block above footer', 'bikashsoft' ),
		'id'            => 'textblock-1',
		'description'   => __( 'Display items in the left just above the footer', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
    
    register_sidebar( array(
		'name'          => __( 'Middle Block above footer', 'bikashsoft' ),
		'id'            => 'textblock-2',
		'description'   => __( 'Display items in the middle just above the footer and replaces defaul gallery', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Right Block above footer', 'bikashsoft' ),
		'id'            => 'textblock-3',
		'description'   => __( 'Display items in the Right just above the footer and replaces Testimonials', 'bikashsoft' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'bikashsoft_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
 function ngo_scripts() {
	 global $bikashsoft_options;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
	wp_enqueue_style( 'ngo-style', get_stylesheet_uri() );

	wp_enqueue_style( 'font-awesome', get_template_directory_uri()."/css/font-awesome.css" );
	wp_enqueue_style( 'flexslider', get_template_directory_uri()."/css/flexslider.css" );	
	wp_enqueue_style( 'bxslider', get_template_directory_uri()."/css/jquery.bxslider.css" );	
	wp_enqueue_style( 'bootstrap', get_template_directory_uri()."/bootstrap/css/bootstrap.css" );
	
	wp_enqueue_script( 'jquery_min_js', get_template_directory_uri() . '/js/jquery-1.9.1.min.js', array('jquery') );
	wp_enqueue_script( 'bootstrap_js', get_template_directory_uri() . '/bootstrap/js/bootstrap.min.js' );
	wp_enqueue_script( 'bxslider_js', get_template_directory_uri() . '/js/jquery.bxslider.min.js' );
	wp_enqueue_script( 'flexslider_js', get_template_directory_uri() . '/js/jquery.flexslider.js' );
wp_enqueue_script( 'custom_js', get_template_directory_uri() . '/js/custom.js' );
	
	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'ngo_scripts' );




/**
* Loads up favicon
*/
function bikashsoft_add_favicon(){
	global $bikashsoft_options;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
	
	if( !empty($bikashsoft_settings[ 'media_upload' ])){
	echo '<link rel="shortcut icon" type="image/png" href="'. esc_url($bikashsoft_settings[ 'media_upload' ]).'"/>';
	}
}
add_action('wp_head', 'bikashsoft_add_favicon');


function bikashsoft_social_cb(){ 
	global $bikashsoft_options;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
	?>
	<div class="socials">
	<?php if(!empty($bikashsoft_settings['bikashsoft_facebook'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_facebook']); ?>" class="facebook" title="Facebook" target="_blank"><span class="fa fa-facebook"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_twitter'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_twitter']); ?>" class="twitter" title="Twitter" target="_blank"><span class="fa fa-twitter"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_gplus'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_gplus']); ?>" class="gplus" title="Google Plus" target="_blank"><span class="fa fa-google-plus"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_youtube'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_youtube']); ?>" class="youtube" title="Youtube" target="_blank"><span class="fa fa-youtube"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_pinterest'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_pinterest']); ?>" class="pinterest" title="Pinterest" target="_blank"><span class="fa fa-pinterest"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_linkedin'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_linkedin']); ?>" class="linkedin" title="Linkedin" target="_blank"><span class="fa fa-linkedin"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_flickr'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_flickr']); ?>" class="flickr" title="Flickr" target="_blank"><span class="fa fa-flickr"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_vimeo'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_vimeo']); ?>" class="vimeo" title="Vimeo" target="_blank"><span class="fa fa-vimeo"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_stumbleupon'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_stumbleupon']); ?>" class="stumbleupon" title="Stumbleupon" target="_blank"><span class="fa fa-stumbleupon"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_instagram'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_instagram']); ?>" class="instagram" title="instagram" target="_blank"><span class="fa fa-instagram"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_sound_cloud'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_sound_cloud']); ?>" class="sound-cloud" title="sound-cloud" target="_blank"><span class="fa fa-soundcloud"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_skype'])){ ?>
	<a href="<?php echo "skype:".esc_attr($bikashsoft_settings['bikashsoft_skype']); ?>" class="skype" title="Skype"><span class="fa fa-skype"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_tumblr'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_tumblr']); ?>" class="tumblr" title="Tumblr"><span class="fa fa-tumblr"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_myspace'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_myspace']); ?>" class="myspace" title="Myspace"><span class="fa fa-myspace"></span></a>
	<?php } ?>

	<?php if(!empty($bikashsoft_settings['bikashsoft_rss'])){ ?>
	<a href="<?php echo esc_url($bikashsoft_settings['bikashsoft_rss']); ?>" class="rss" title="RSS" target="_blank"><span class="fa fa-rss"></span></a>
	<?php } ?>
	</div>
<?php } 

add_action( 'bikashsoft_social_links', 'bikashsoft_social_cb', 10 );	




function bikashsoft_excerpt( $bikashsoft_content , $bikashsoft_letter_count ){
	$bikashsoft_striped_content = strip_shortcodes($bikashsoft_content);
	$bikashsoft_striped_content = strip_tags($bikashsoft_striped_content);
	$bikashsoft_excerpt = mb_substr($bikashsoft_striped_content, 0, $bikashsoft_letter_count );
	if(strlen($bikashsoft_striped_content) > strlen($bikashsoft_excerpt)){
		$bikashsoft_excerpt .= "...";
	}
	return $bikashsoft_excerpt;
}


function bikashsoft_bxslidercb(){
	global $bikashsoft_options, $post;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
    $home_template = $bikashsoft_settings['bikashsoft_home_template'];
    ($bikashsoft_settings['slider_show_pager'] == 'yes1' || empty($bikashsoft_settings['slider_show_pager'])) ? ($a='true') : ($a='false');
    ($bikashsoft_settings['slider_show_controls'] == 'yes2' || empty($bikashsoft_settings['slider_show_controls'])) ? ($b='true') : ($b='false');
    ($bikashsoft_settings['slider_mode'] == 'slide' || empty($bikashsoft_settings['slider_mode'])) ? ($c='horizontal') : ($c='fade');
    ($bikashsoft_settings['slider_auto'] == 'yes3' || empty($bikashsoft_settings['slider_auto'])) ? ($d='true') : ($d='false');
	empty($bikashsoft_settings['slider_pause']) ? ($e ='5000') : ($e = $bikashsoft_settings['slider_pause']);

	if( $bikashsoft_settings['show_slider'] !='no') { 
	if((isset($bikashsoft_settings['slider1']) && !empty($bikashsoft_settings['slider1'])) 
		|| (isset($bikashsoft_settings['slider2']) && !empty($bikashsoft_settings['slider2'])) 
		|| (isset($bikashsoft_settings['slider3']) && !empty($bikashsoft_settings['slider3']))
		|| (isset($bikashsoft_settings['slider4']) && !empty($bikashsoft_settings['slider4'])) 
		|| (isset($bikashsoft_settings['slider_cat']) && !empty($bikashsoft_settings['slider_cat']))
	){
    
	?>
		<script type="text/javascript">
        jQuery(function(){
			jQuery('.bx-slider').bxSlider({
				adaptiveHeight:true,
				pager:<?php echo esc_attr($a); ?>,
				controls:<?php echo esc_attr($b); ?>,
				mode:'<?php echo esc_attr($c); ?>',
				auto :<?php echo esc_attr($d); ?>,
				pause: '<?php echo esc_attr($e); ?>',
				<?php if($bikashsoft_settings['slider_speed']) {?>
				speed:'<?php echo esc_attr($bikashsoft_settings['slider_speed']); ?>',
				<?php } ?>
                <?php if($home_template == 'template_two'|| $home_template == ''){ ?>
                nextSelector: '#slider-next',
                prevSelector: '#slider-prev',
                
                <?php } ?>
			});
		});
    </script>
    <?php 

        if($bikashsoft_settings['slider_options'] == 'single_post_slider'){
        	if(!empty($bikashsoft_settings['slider1']) || !empty($bikashsoft_settings['slider2']) || !empty($bikashsoft_settings['slider3']) || !empty($bikashsoft_settings['slider4'])){
        		$sliders = array($bikashsoft_settings['slider1'],$bikashsoft_settings['slider2'],$bikashsoft_settings['slider3'],$bikashsoft_settings['slider4']);
				$remove = array(0);
			    $sliders = array_diff($sliders, $remove);  ?>

			    <div class="bx-slider">
			    <?php
			    foreach ($sliders as $slider){
				$args = array (
				'p' => $slider
				);

					$loop = new WP_query( $args );
					if($loop->have_posts()){ 
					while($loop->have_posts()) : $loop-> the_post(); 
					$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false ); 
					?>
					<div class="slides">
						
							<img alt="<?php echo get_the_title(); ?>" src="<?php echo esc_url($image[0]); ?>">
							
							<?php if($bikashsoft_settings['slider_caption']=='yes4'):?>
							<div class="slider-caption">
								<div class="ak-container">
									<h1 class="caption-title"><?php the_title();?></h1>
									<h2 class="caption-description"><?php echo get_the_content();?></h2>
								</div>
							</div>
							<?php  endif; ?>
			
		            </div>
					<?php endwhile;
					}
				} ?>
			    </div>
                <?php if($home_template == 'template_two' || $home_template == ''){ ?>
                <span id="slider-prev"></span><span id="slider-next"></span>
                <?php } ?>
        	<?php
        	}

        }elseif ($bikashsoft_settings['slider_options'] == 'cat_post_slider') { ?>
        	<div class="bx-slider">
			<?php
			$loop = new WP_Query(array(
					'cat' => $bikashsoft_settings['slider_cat'],
					'posts_per_page' => -1
				));
				if($loop->have_posts()){ 
				while($loop->have_posts()) : $loop-> the_post(); 
				$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false ); 
				?>
				<div class="slides">
						
					<img alt="<?php echo get_the_title(); ?>" src="<?php echo esc_url($image[0]); ?>">
							
					<?php if($bikashsoft_settings['slider_caption']=='yes4'):?>
					<div class="slider-caption">
						<div class="ak-container">
							<h1 class="caption-title"><?php the_title();?></h1>
							<h2 class="caption-description"><?php echo get_the_content();?></h2>
						</div>
					</div>
					<?php  endif; ?>
			
		            </div>
					<?php endwhile;
					} ?>
			</div>
            <span id="slider-prev"></span><span id="slider-next"></span>
        <?php
    	}
    	}else{ ?>

    	<script type="text/javascript">
        jQuery(function(){
			jQuery('.bx-slider').bxSlider({
				pager:<?php echo esc_attr($a); ?>,
				controls:<?php echo esc_attr($b); ?>,
				mode:'<?php echo esc_attr($c); ?>',
				auto :<?php echo esc_attr($d); ?>,
				pause: '<?php echo esc_attr($e); ?>',
				<?php if($bikashsoft_settings['slider_speed']) {?>
				speed:'<?php echo esc_attr($bikashsoft_settings['slider_speed']); ?>',
				<?php } ?>
                <?php if($home_template == 'template_two'|| $home_template == ''){ ?>
                nextSelector: '#slider-next',
                prevSelector: '#slider-prev',
                <?php } ?>
			});
		});
        </script>
        <div class="bx-slider">
			<div class="slides">
				<img src="<?php echo get_template_directory_uri(); ?>/images/slides/slider1.jpg" alt="slider1">
                <?php if($bikashsoft_settings['slider_caption']=='yes4' || empty($bikashsoft_settings['slider_caption'])):?>
				<div class="slider-caption">
					<div class="ak-container">
						<h1 class="caption-title">Bikashsoft Technology</h1>
						<h2 class="caption-description">Free Responsive, multi-purpose, business wordpress theme, perfect for any business on any device.</h2>
					</div>
				</div>
                <?php  endif; ?>
			</div>
					
			<div class="slides">
				<img src="<?php echo get_template_directory_uri(); ?>/images/slides/slider1.jpg" alt="slider2">
                <?php if($bikashsoft_settings['slider_caption']=='yes4' || empty($bikashsoft_settings['slider_caption'])):?>
				<div class="slider-caption">
					<div class="ak-container">
						<h1 class="caption-title">Easy Customization</h1>
						<h2 class="caption-description">A free theme with powerful theme options for customization. Style your wordpress and see changes live!</h2>
					</div>
				</div>
                <?php  endif; ?>
			</div>
		</div>
        <?php if($home_template == 'template_two' || $home_template == ''){ ?>
                <span id="slider-prev"></span><span id="slider-next"></span>
                <?php } ?>
	<?php
	}
}
}

add_action('bikashsoft_bxslider','bikashsoft_bxslidercb', 10);



function bikashsoft_custom_css(){
	global $bikashsoft_options;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
	echo '<style type="text/css">';
		echo esc_html($bikashsoft_settings['custom_css']);
	echo '</style>';
}

add_action('wp_head','bikashsoft_custom_css');

function bikashsoft_call_to_action_cb()
{
	global $bikashsoft_options;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
    $home_template = $bikashsoft_settings['bikashsoft_home_template'];
    if($home_template == ''){
        ?>
    	<section id="call-to-action">
    	<div class="ak-container">
    		<h4>Check Our AccessPress Pro Theme - A premium version of AccessPres Lite</h4>
    		<a class="action-btn" href="#">Check Now</a>
    	</div>
    	</section>
<?php
    }
	if(!empty($bikashsoft_settings['action_text']))
    { ?>
    	<section id="call-to-action">
    	<div class="ak-container">
    		<h4><?php echo $bikashsoft_settings['action_text']; ?></h4>
    		<a class="action-btn" href="<?php echo esc_url($bikashsoft_settings['action_btn_link']); ?>"><?php echo esc_attr($bikashsoft_settings['action_btn_text']); ?></a>
    	</div>
    	</section>
<?php }
}

add_action('bikashsoft_call_to_action','bikashsoft_call_to_action_cb', 10);

function bikashsoft_exclude_cat_from_blog($query) {
	global $bikashsoft_options;
	$bikashsoft_settings = get_option( 'bikashsoft_options', $bikashsoft_options );
	$bikashsoft_exclude_cat = array($bikashsoft_settings['event_cat'],$bikashsoft_settings['testimonial_cat'], $bikashsoft_settings['slider_cat'], $bikashsoft_settings['portfolio_cat']);

	if(!empty($bikashsoft_exclude_cat)):
	$cats = array();
	foreach($bikashsoft_exclude_cat as $value){
	    if(!empty($value) && $value != 0){
	        $cats[] = -$value; 
	    }
	}
	if(!empty($cats)){
	    $category = join( "," , $cats);
	    if ( $query->is_home() ) {
	    $query->set('cat', $category);
	    }
	}
	return $query;
	endif;
}

add_filter('pre_get_posts', 'bikashsoft_exclude_cat_from_blog');

function bikashsoft_admin_notice() {
    global $pagenow;
    if (is_admin() && isset($_GET['activated'] ) && $pagenow == "themes.php" ) {
    ?>
    <div class="updated">
        <p><?php echo sprintf(__( 'Go to <a href="%s">Theme Options Panel</a> to set up the website.', 'bikashsoft' ), esc_url(admin_url('/themes.php?page=theme_options'))); ?></p>
    </div>
    <?php
    }
}

add_action( 'admin_notices', 'bikashsoft_admin_notice' );

function accesspress_check_old_template(){
    $settings = get_option( 'bikashsoft_options');
    $temp_val = $settings['template_option_selected'];
    if($temp_val != 'yes'){
        if(  !empty($settings['menu_alignment'])){ 
            
            $settings['bikashsoft_home_template'] = 'template_one';
            
            update_option('bikashsoft_options', $settings);
            
        }
    }
}
add_action( 'init', 'accesspress_check_old_template' );

